@@ -3,22 +3,14 @@ import logging
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
-from mayan.apps.acls.links import link_acl_list
-from mayan.apps.acls.permissions import (
-    permission_acl_edit, permission_acl_view
-)
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.html_widgets import TwoStateWidget
 from mayan.apps.common.menus import (
-    menu_list_facet, menu_multi_item, menu_object, menu_secondary,
-    menu_setup
+    menu_list_facet, menu_multi_item, menu_object, menu_return,
+    menu_secondary, menu_setup
 )
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
-from mayan.apps.events.links import (
-    link_events_for_object, link_object_event_types_user_subcriptions_list,
-)
-from mayan.apps.events.permissions import permission_events_view
 from mayan.apps.navigation.classes import SourceColumn
+from mayan.apps.views.html_widgets import TwoStateWidget
 
 from .classes import ImportSetupActionBackend, ImportSetupBackend, ModelFiler
 from .events import (
@@ -31,7 +23,7 @@ from .links import (
     link_import_setup_clear, link_import_setup_edit,
     link_import_setup_item_multiple_delete,
     link_import_setup_item_document_list,
-    link_import_setup_item_multiple_process, link_import_setup_items_list,
+    link_import_setup_item_multiple_process, link_import_setup_item_list,
     link_import_setup_logs, link_import_setup_multiple_clear,
     link_import_setup_multiple_populate, link_import_setup_multiple_process,
     link_import_setup_populate, link_import_setup_process,
@@ -88,13 +80,12 @@ class ImporterApp(MayanAppConfig):
             )
         )
 
-        ModelFiler(bulk_size=250, model=ImportSetupItem)
+        ModelFiler(model=ImportSetupItem)
 
         ModelPermission.register(
             model=ImportSetup, permissions=(
-                permission_acl_edit, permission_acl_view,
-                permission_events_view, permission_import_setup_delete,
-                permission_import_setup_edit, permission_import_setup_process,
+                permission_import_setup_delete, permission_import_setup_edit,
+                permission_import_setup_process,
                 permission_import_setup_view, permission_model_filer_load,
                 permission_model_filer_save
             )
@@ -172,9 +163,7 @@ class ImporterApp(MayanAppConfig):
 
         menu_list_facet.bind_links(
             links=(
-                link_acl_list, link_events_for_object,
-                link_import_setup_items_list, link_import_setup_logs,
-                link_object_event_types_user_subcriptions_list,
+                link_import_setup_item_list, link_import_setup_logs
             ), sources=(ImportSetup,)
         )
 
@@ -182,24 +171,47 @@ class ImporterApp(MayanAppConfig):
             links=(
                 link_import_setup_multiple_clear,
                 link_import_setup_multiple_populate,
-                link_import_setup_multiple_process,
+                link_import_setup_multiple_process
             ), sources=(ImportSetup,)
         )
         menu_object.bind_links(
             links=(
                 link_import_setup_delete, link_import_setup_edit,
-                link_import_setup_process, link_import_setup_clear,
-                link_import_setup_populate,
-                link_model_filer_load, link_model_filer_save
+                link_import_setup_process
             ), sources=(ImportSetup,)
         )
         menu_secondary.bind_links(
-            links=(link_import_setup_backend_selection, link_import_setup_list),
+            links=(
+                link_import_setup_backend_selection,
+            ),
             sources=(
-                ImportSetup, 'importer:import_setup_backend_selection',
+                ImportSetup, 'importer:import_setup_items_list',
                 'importer:import_setup_create', 'importer:import_setup_list'
             )
         )
+
+        menu_secondary.bind_links(
+            links=(
+                link_import_setup_clear, link_import_setup_populate,
+                link_model_filer_load, link_model_filer_save
+            ),
+            sources=(
+                'importer:import_setup_load',
+                'importer:import_setup_items_list',
+                'importer:import_setup_populate',
+                'importer:import_setup_save'
+            )
+        )
+
+        menu_return.bind_links(
+            links=(
+                link_import_setup_list,
+            ),
+            sources=(
+                ImportSetup, ImportSetupAction, ImportSetupItem
+            )
+        )
+
         menu_setup.bind_links(
             links=(link_import_setup_setup,)
         )
