@@ -2,23 +2,33 @@ import csv
 import io
 import json
 import logging
+import shutil
+
+from furl import furl
 
 from django.apps import apps
-from django.core.files import File
 from django.db import models
-from django.utils import six
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-# Change this to mayan.apps.common.class_mixins for Mayan EDMS 3.5
 from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
+from mayan.apps.locales.utils import to_language
 from mayan.apps.storage.utils import NamedTemporaryFile
 from mayan.apps.templating.classes import Template
 
 from .exceptions import ImportSetupActionError
+from .permissions import permission_import_setup_view
 
 logger = logging.getLogger(name=__name__)
 
 __all__ = ('ImportSetupActionBackend', 'ImportSetupBackend',)
+MESSAGE_MODEL_FILER_SAVE_BODY = _(
+    'The model data from object type %(save_file_title)s has been '
+    'exported and is available for download using the '
+    'link: %(download_url)s or from '
+    'the downloads area (%(download_list_url)s).'
+)
+MESSAGE_MODEL_FILER_SAVE_SUBJECT = _('Model data export.')
 
 
 class ImportSetupActionBackendMetaclass(type):
@@ -37,16 +47,11 @@ class ImportSetupActionBackendMetaclass(type):
         return new_class
 
 
-class ImportSetupActionBackendBase(AppsModuleLoaderMixin):
-    fields = ()
-
-
 class ImportSetupActionBackend(
-    six.with_metaclass(
-        ImportSetupActionBackendMetaclass, ImportSetupActionBackendBase
-    )
+    AppsModuleLoaderMixin, metaclass=ImportSetupActionBackendMetaclass
 ):
     _loader_module_name = 'import_setup_actions'
+    fields = ()
 
     @classmethod
     def clean(cls, request, cleaned_data, dynamic_form_data):
@@ -144,31 +149,11 @@ class ImportSetupBackendMetaclass(type):
         return new_class
 
 
-class ImportSetupBackendBase(AppsModuleLoaderMixin):
-    """
-    Base class for the backends.
-
-    The fields attribute is a list of dictionaries with the format:
-    {
-        'name': ''  # Field internal name
-        'label': ''  # Label to show to users
-        'initial': ''  # Field initial value
-        'default': ''  # Default value.
-    }
-
-    """
-    fields = {}
-
-    @classmethod
-    def get_class_fields(cls):
-        backend_field_list = getattr(cls, 'fields', {}).keys()
-        return getattr(cls, 'class_fields', backend_field_list)
-
-
 class ImportSetupBackend(
-    six.with_metaclass(ImportSetupBackendMetaclass, ImportSetupBackendBase)
+    AppsModuleLoaderMixin, metaclass=ImportSetupBackendMetaclass
 ):
     _loader_module_name = 'importers'
+    fields = {}
 
     @classmethod
     def get(cls, name):
@@ -188,6 +173,11 @@ class ImportSetupBackend(
             ], key=lambda x: x[1]
         )
 
+    @classmethod
+    def get_class_fields(cls):
+        backend_field_list = getattr(cls, 'fields', {}).keys()
+        return getattr(cls, 'class_fields', backend_field_list)
+
     def __init__(self, **kwargs):
         for class_field in getattr(self, 'class_fields', ()):
             setattr(self, class_field, kwargs.get(class_field, None))
@@ -227,44 +217,64 @@ class ModelFiler:
     def get(cls, full_model_name):
         return cls._registry[full_model_name]
 
-    def __init__(self, model, bulk_size):
+    def __init__(self, model, bulk_size=None):
         self.model = model
         self.bulk_size = bulk_size
         self.__class__._registry[
             ModelFiler.get_full_model_name(model=model)
         ] = self
 
-    def load(self, shared_upload_file, field_defaults=None):
+    def get_model_full_name(self):
+        return ModelFiler.get_full_model_name(model=self.model)
+
+    def items_load(self, shared_upload_file, field_defaults=None, user=None):
         if not field_defaults:
             field_defaults = {}
 
         field_names = ModelFiler.get_field_names(model=self.model)
 
+        manager = self.model._meta.default_manager
+
+        if self.bulk_size:
+            manager.filter(**field_defaults).delete()
+        else:
+            for instance in manager.filter(**field_defaults):
+                instance.delete()
+
         with shared_upload_file.open() as file_object_binary:
             with io.TextIOWrapper(file_object_binary) as file_object:
                 file_object.readline()  # Header
                 reader = csv.DictReader(file_object, fieldnames=field_names)
-                manager = self.model._meta.default_manager
 
-                bulk_list = []
-                bulk_count = 0
+                if self.bulk_size:
+                    bulk_list = []
+                    bulk_count = 0
 
-                for row in reader:
-                    row.update(**field_defaults)
-                    bulk_list.append(self.model(**row))
-                    bulk_count = bulk_count + 1
-                    if bulk_count > self.bulk_size:
-                        manager.bulk_create(bulk_list)
-                        bulk_list = []
-                        bulk_count = 0
+                    for row in reader:
+                        row.update(**field_defaults)
+                        bulk_list.append(self.model(**row))
+                        bulk_count += 1
 
-                        manager.bulk_create(bulk_list)
+                        if bulk_count > self.bulk_size:
+                            manager.bulk_create(bulk_list)
+                            bulk_list = []
+                            bulk_count = 0
 
-                manager.bulk_create(bulk_list)
+                    manager.bulk_create(bulk_list)
+                else:
+                    for row in reader:
+                        row.update(**field_defaults)
+                        manager.create(**row)
 
-    def save(self, filter_kwargs=None):
-        SharedUploadedFile = apps.get_model(
-            app_label='common', model_name='SharedUploadedFile'
+    def items_save(
+        self, save_file_title, filter_kwargs=None,
+        organization_installation_url=None, user=None
+    ):
+        DownloadFile = apps.get_model(
+            app_label='storage', model_name='DownloadFile'
+        )
+        Message = apps.get_model(
+            app_label='messaging', model_name='Message'
         )
 
         if not filter_kwargs:
@@ -274,15 +284,55 @@ class ModelFiler:
 
         queryset = self.model._meta.default_manager.filter(**filter_kwargs)
 
-        with NamedTemporaryFile(mode='r+') as file_object:
-            writer = csv.DictWriter(file_object, fieldnames=field_names)
+        download_file = DownloadFile(
+            content_object=queryset.first(), filename='{}-export.csv'.format(self.get_model_full_name()),
+            label=_('Export of %s to CSV') % save_file_title,
+            permission=permission_import_setup_view.stored_permission
+        )
+        download_file._event_actor = user
+        download_file.save()
+
+        with NamedTemporaryFile(mode='r+') as temporary_file_object:
+            writer = csv.DictWriter(f=temporary_file_object, fieldnames=field_names)
 
             writer.writeheader()
             for item in queryset.values(*field_names):
                 writer.writerow(item)
 
-            file_object.seek(0)
+            temporary_file_object.seek(0)
 
-            return SharedUploadedFile.objects.create(
-                file=File(file_object),
+            with download_file.open(mode='w+') as download_file_object:
+                shutil.copyfileobj(
+                    fsrc=temporary_file_object, fdst=download_file_object
+                )
+
+        if user:
+            download_list_url = furl(organization_installation_url).join(
+                reverse(
+                    viewname='storage:download_file_list'
+                )
+            ).tostr()
+
+            download_url = furl(organization_installation_url).join(
+                reverse(
+                    viewname='storage:download_file_download',
+                    kwargs={'download_file_id': download_file.pk}
+                )
+            ).tostr()
+
+            Message.objects.create(
+                sender_object=download_file,
+                user=user,
+                subject=to_language(
+                    language=user.locale_profile.language,
+                    promise=MESSAGE_MODEL_FILER_SAVE_SUBJECT
+                ),
+                body=to_language(
+                    language=user.locale_profile.language,
+                    promise=MESSAGE_MODEL_FILER_SAVE_BODY
+                ) % {
+                    'download_list_url': download_list_url,
+                    'download_url': download_url,
+                    'save_file_title': save_file_title
+                }
             )
