@@ -1,7 +1,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.navigation.classes import Link
-from mayan.apps.navigation.utils import get_cascade_condition
+from mayan.apps.navigation.utils import factory_condition_queryset_access
 
 from .icons import (
     icon_import_setup_action_delete, icon_import_setup_action_edit,
@@ -57,7 +57,7 @@ link_import_setup_logs = Link(
     view='importer:import_setup_log_list'
 )
 link_import_setup_setup = Link(
-    condition=get_cascade_condition(
+    condition=factory_condition_queryset_access(
         app_label='importer', model_name='ImportSetup',
         object_permission=permission_import_setup_view,
         view_permission=permission_import_setup_create,
@@ -100,11 +100,11 @@ link_import_setup_action_backend_selection = Link(
 link_import_setup_populate = Link(
     args='resolved_object.pk',
     icon=icon_import_setup_populate,
-    permissions=(permission_import_setup_process,), text=_('Prepare'),
+    permissions=(permission_import_setup_process,), text=_('Populate items'),
     view='importer:import_setup_populate'
 )
 link_import_setup_multiple_populate = Link(
-    icon=icon_import_setup_populate, text=_('Prepare'),
+    icon=icon_import_setup_populate, text=_('Populate items'),
     view='importer:import_setup_multiple_populate'
 )
 link_import_setup_process = Link(
@@ -134,7 +134,7 @@ link_import_setup_item_document_list = Link(
     permissions=(permission_import_setup_view,), text=_('Documents'),
     view='importer:import_setup_item_document_list'
 )
-link_import_setup_items_list = Link(
+link_import_setup_item_list = Link(
     args='resolved_object.pk',
     icon=icon_import_setup_items_list,
     permissions=(permission_import_setup_view,), text=_('Items'),
@@ -157,10 +157,10 @@ link_import_setup_item_multiple_process = Link(
 link_model_filer_load = Link(
     args='resolved_object.pk', icon=icon_model_filer_load,
     permissions=(permission_model_filer_load,),
-    text=_('Load'), view='importer:import_setup_load'
+    text=_('Load items'), view='importer:import_setup_load'
 )
 link_model_filer_save = Link(
     args='resolved_object.pk', icon=icon_model_filer_save,
     permissions=(permission_model_filer_save,),
-    text=_('Save'), view='importer:import_setup_save'
+    text=_('Save items'), view='importer:import_setup_save'
 )
