@@ -4,6 +4,7 @@ from django.conf import settings
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.db import models
 from django.db.models import Max
+from django.urls import reverse
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
@@ -127,6 +128,11 @@ class ImportSetup(BackendModelMixin, models.Model):
     def clear(self):
         self.items.all().delete()
 
+    def get_absolute_url(self):
+        return reverse(
+            viewname='importer:import_setup_list'
+        )
+
     def get_backend_instance(self):
         kwargs = self.get_backend_data()
 
@@ -241,7 +247,8 @@ class ImportSetup(BackendModelMixin, models.Model):
 
         count = 0
         try:
-            queryset = self.items.filter(state=ITEM_STATE_NONE)
+            # Only schedule items that have not succeeded in being imported.
+            queryset = self.items.exclude(state=ITEM_STATE_DOWNLOADED)
             iterator = queryset.iterator()
 
             while True:
@@ -379,6 +386,13 @@ class ImportSetupItem(models.Model):
     def __str__(self):
         return self.identifier
 
+    def get_absolute_url(self):
+        return reverse(
+            viewname='importer:import_setup_items_list', kwargs={
+                'import_setup_id': self.import_setup.pk
+            }
+        )
+
     def check_valid(self):
         backend_instance = self.import_setup.get_backend_instance()
         return backend_instance.check_valid(
@@ -490,6 +504,15 @@ class ImportSetupItem(models.Model):
                     for action in self.import_setup.actions.filter(enabled=True):
                         action.execute(context=context)
 
+    def save(self, *args, **kwargs):
+        if not self.state:
+            self.state = ITEM_STATE_NONE
+
+        if not self.state_data:
+            self.state_data = ''
+
+        super().save(*args, **kwargs)
+
 
 class ImportSetupLog(models.Model):
     import_setup = models.ForeignKey(
