@@ -1,13 +1,17 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.task_manager.classes import CeleryQueue
-from mayan.apps.task_manager.workers import worker_c
+from mayan.apps.task_manager.classes import CeleryQueue, Worker
+
+worker_importer = Worker(
+    maximum_memory_per_child=300000, maximum_tasks_per_child=100,
+    name='worker_importer'
+)
 
 queue_importer = CeleryQueue(
-    label=_('Importer'), name='importer', worker=worker_c
+    label=_('Importer'), name='importer', worker=worker_importer
 )
 queue_model_filer = CeleryQueue(
-    label=_('Model filer'), name='filer', worker=worker_c
+    label=_('Model filer'), name='filer', worker=worker_importer
 )
 
 queue_importer.add_task_type(
