@@ -145,6 +145,29 @@ class ImportSetupActionViewTestMixin:
         )
 
 
+class ImportSetupItemAPIViewTestMixin:
+    def _request_test_import_setup_clear_api_view(self):
+        return self.post(
+            viewname='rest_api:importsetup-clear', kwargs={
+                'import_setup_id': self.test_import_setup.pk
+            }
+        )
+
+    def _request_test_import_setup_populate_api_view(self):
+        return self.post(
+            viewname='rest_api:importsetup-populate', kwargs={
+                'import_setup_id': self.test_import_setup.pk
+            }
+        )
+
+    def _request_test_import_setup_process_api_view(self):
+        return self.post(
+            viewname='rest_api:importsetup-process', kwargs={
+                'import_setup_id': self.test_import_setup.pk
+            }
+        )
+
+
 class ImportSetupTestMixin:
     def _create_test_import_setup(self):
         self.test_import_setup = ImportSetup.objects.create(
