@@ -1,5 +1,11 @@
-from mayan.apps.common.tests.base import GenericViewTestCase
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.events import (
+    event_document_created, event_document_file_created,
+    event_document_file_edited, event_document_version_created,
+    event_document_version_page_created
+)
+from mayan.apps.documents.models.document_models import Document
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from credentials.tests.mixins import StoredCredentialTestMixin
 
@@ -49,8 +55,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_backend_selection_view_with_permissions(self):
         self.grant_access(
@@ -68,8 +74,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_create_view_no_permissions(self):
         import_setup_action_count = ImportSetupAction.objects.count()
@@ -83,8 +89,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_create_view_with_permissions(self):
         self.grant_access(
@@ -101,8 +107,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count + 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_delete_view_no_permissions(self):
         self._create_test_import_setup_action()
@@ -118,8 +124,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_delete_view_with_access(self):
         self._create_test_import_setup_action()
@@ -140,8 +146,8 @@ class ImportSetupActionViewTestCase(
             ImportSetupAction.objects.count(), import_setup_action_count - 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_edit_view_no_permissions(self):
         self._create_test_import_setup_action()
@@ -158,8 +164,8 @@ class ImportSetupActionViewTestCase(
             self.test_import_setup_action.label, import_setup_action_label
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_edit_view_with_access(self):
         self._create_test_import_setup_action()
@@ -181,8 +187,8 @@ class ImportSetupActionViewTestCase(
             self.test_import_setup_action.label, import_setup_action_label
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_list_view_with_no_permission(self):
         self._create_test_import_setup_action()
@@ -195,14 +201,15 @@ class ImportSetupActionViewTestCase(
             status_code=404
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_action_list_view_with_access(self):
         self._create_test_import_setup_action()
 
         self.grant_access(
-            obj=self.test_import_setup, permission=permission_import_setup_view
+            obj=self.test_import_setup,
+            permission=permission_import_setup_view
         )
 
         self._clear_events()
@@ -213,8 +220,8 @@ class ImportSetupActionViewTestCase(
             status_code=200
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
 
 class ImportSetupViewTestCase(
@@ -283,10 +290,13 @@ class ImportSetupViewTestCase(
             ImportSetup.objects.count(), import_setup_count + 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event.actor, self._test_case_user)
-        self.assertEqual(event.target, self.test_import_setup)
-        self.assertEqual(event.verb, event_import_setup_created.id)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self.test_import_setup)
+        self.assertEqual(events[0].verb, event_import_setup_created.id)
 
     def test_import_setup_delete_view_no_permissions(self):
         self._create_test_import_setup()
@@ -300,8 +310,8 @@ class ImportSetupViewTestCase(
 
         self.assertEqual(ImportSetup.objects.count(), import_setup_count)
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_delete_view_with_access(self):
         self._create_test_import_setup()
@@ -322,8 +332,8 @@ class ImportSetupViewTestCase(
             ImportSetup.objects.count(), import_setup_count - 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_edit_view_no_permissions(self):
         self._create_test_import_setup()
@@ -338,8 +348,8 @@ class ImportSetupViewTestCase(
         self.test_import_setup.refresh_from_db()
         self.assertEqual(self.test_import_setup.label, import_setup_label)
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_edit_view_with_access(self):
         self._create_test_import_setup()
@@ -359,10 +369,13 @@ class ImportSetupViewTestCase(
         self.test_import_setup.refresh_from_db()
         self.assertNotEqual(self.test_import_setup.label, import_setup_label)
 
-        event = self._get_test_object_event()
-        self.assertEqual(event.actor, self._test_case_user)
-        self.assertEqual(event.target, self.test_import_setup)
-        self.assertEqual(event.verb, event_import_setup_edited.id)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self.test_import_setup)
+        self.assertEqual(events[0].verb, event_import_setup_edited.id)
 
     def test_import_setup_list_view_with_no_permission(self):
         self._create_test_import_setup()
@@ -375,8 +388,8 @@ class ImportSetupViewTestCase(
             status_code=200
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_list_view_with_access(self):
         self._create_test_import_setup()
@@ -394,8 +407,8 @@ class ImportSetupViewTestCase(
             status_code=200
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
 
 class ImportSetupItemViewTestCase(
@@ -425,8 +438,8 @@ class ImportSetupItemViewTestCase(
             self.test_import_setup.items.count(), import_setup_item_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_clear_view_with_access(self):
         self._create_test_import_setup_item()
@@ -447,8 +460,8 @@ class ImportSetupItemViewTestCase(
             self.test_import_setup.items.count(), import_setup_item_count - 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_populate_view_no_permission(self):
         import_setup_item_count = self.test_import_setup.items.count()
@@ -462,8 +475,8 @@ class ImportSetupItemViewTestCase(
             self.test_import_setup.items.count(), import_setup_item_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_populate_view_with_access(self):
         self.grant_access(
@@ -482,10 +495,22 @@ class ImportSetupItemViewTestCase(
             self.test_import_setup.items.count(), import_setup_item_count + 1
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event.actor, self.test_import_setup)
-        self.assertEqual(event.target, self.test_import_setup)
-        self.assertEqual(event.verb, event_import_setup_populate_ended.id)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 2)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self.test_import_setup)
+        self.assertEqual(events[0].target, self.test_import_setup)
+        self.assertEqual(
+            events[0].verb, event_import_setup_populate_started.id
+        )
+
+        self.assertEqual(events[1].action_object, None)
+        self.assertEqual(events[1].actor, self.test_import_setup)
+        self.assertEqual(events[1].target, self.test_import_setup)
+        self.assertEqual(
+            events[1].verb, event_import_setup_populate_ended.id
+        )
 
     def test_import_setup_process_view_no_permission(self):
         self._create_test_import_setup_item()
@@ -501,8 +526,8 @@ class ImportSetupItemViewTestCase(
             self.test_document_type.documents.count(), document_count
         )
 
-        event = self._get_test_object_event()
-        self.assertEqual(event, None)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_import_setup_process_view_with_access(self):
         self._create_test_import_setup_item()
@@ -522,16 +547,55 @@ class ImportSetupItemViewTestCase(
             self.test_document_type.documents.count(), document_count + 1
         )
 
-        events = self._get_test_object_events()
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 8)
+
+        test_document = Document.objects.last()
+        test_document_file = test_document.file_latest
+        test_document_version = test_document.versions.last()
+        test_document_version_page = test_document_version.pages.first()
+
         self.assertEqual(events[0].actor, self.test_import_setup)
         self.assertEqual(events[0].target, self.test_import_setup)
-        self.assertEqual(events[0].verb, event_import_setup_process_started.id)
+        self.assertEqual(
+            events[0].verb, event_import_setup_process_started.id
+        )
 
-        self.assertEqual(events[1].action_object, self.test_import_setup)
-        self.assertEqual(events[1].actor, self.test_import_setup_item)
-        self.assertEqual(events[1].target, self.test_import_setup_item)
-        self.assertEqual(events[1].verb, event_import_setup_item_completed.id)
+        self.assertEqual(events[1].action_object, self.test_document_type)
+        self.assertEqual(events[1].actor, test_document)
+        self.assertEqual(events[1].target, test_document)
+        self.assertEqual(events[1].verb, event_document_created.id)
 
-        self.assertEqual(events[2].actor, self.test_import_setup)
-        self.assertEqual(events[2].target, self.test_import_setup)
-        self.assertEqual(events[2].verb, event_import_setup_process_ended.id)
+        self.assertEqual(events[2].action_object, test_document)
+        self.assertEqual(events[2].actor, test_document_file)
+        self.assertEqual(events[2].target, test_document_file)
+        self.assertEqual(events[2].verb, event_document_file_created.id)
+
+        self.assertEqual(events[3].action_object, test_document)
+        self.assertEqual(events[3].actor, test_document_file)
+        self.assertEqual(events[3].target, test_document_file)
+        self.assertEqual(events[3].verb, event_document_file_edited.id)
+
+        self.assertEqual(events[4].action_object, test_document)
+        self.assertEqual(events[4].actor, test_document_version)
+        self.assertEqual(events[4].target, test_document_version)
+        self.assertEqual(events[4].verb, event_document_version_created.id)
+
+        self.assertEqual(events[5].action_object, test_document_version)
+        self.assertEqual(events[5].actor, test_document_version_page)
+        self.assertEqual(events[5].target, test_document_version_page)
+        self.assertEqual(
+            events[5].verb, event_document_version_page_created.id
+        )
+
+        self.assertEqual(events[6].action_object, self.test_import_setup)
+        self.assertEqual(events[6].actor, self.test_import_setup_item)
+        self.assertEqual(events[6].target, self.test_import_setup_item)
+        self.assertEqual(
+            events[6].verb, event_import_setup_item_completed.id
+        )
+
+        self.assertEqual(events[7].action_object, None)
+        self.assertEqual(events[7].actor, self.test_import_setup)
+        self.assertEqual(events[7].target, self.test_import_setup)
+        self.assertEqual(events[7].verb, event_import_setup_process_ended.id)
