@@ -8,12 +8,12 @@ from django.urls import reverse, reverse_lazy
 from django.utils.translation import ungettext, ugettext_lazy as _
 
 from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.organizations.utils import get_organization_installation_url
 from mayan.apps.storage.models import SharedUploadedFile
 from mayan.apps.views.generics import (
     ConfirmView, FormView, MultipleObjectConfirmActionView,
     SingleObjectDeleteView, SingleObjectDynamicFormCreateView,
-    SingleObjectDynamicFormEditView, SingleObjectDownloadView,
-    SingleObjectListView
+    SingleObjectDynamicFormEditView, SingleObjectListView
 )
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 
@@ -28,8 +28,9 @@ from .icons import (
     icon_import_setup_list, icon_import_setup_log_list
 )
 from .links import (
-    link_import_setup_action_backend_selection, link_import_setup_backend_selection,
-    link_import_setup_populate
+    link_import_setup_action_backend_selection,
+    link_import_setup_backend_selection, link_import_setup_populate,
+    link_model_filer_load
 )
 from .models import ImportSetup, ImportSetupAction, ImportSetupItem
 from .permissions import (
@@ -164,14 +165,6 @@ class ImportSetupActionEditView(SingleObjectDynamicFormEditView):
             '_event_actor': self.request.user
         }
 
-    def get_post_action_redirect(self):
-        return reverse(
-            viewname='importer:import_setup_action_list',
-            kwargs={
-                'import_setup_id': self.object.import_setup.pk
-            }
-        )
-
 
 class ImportSetupActionListView(ExternalObjectViewMixin, SingleObjectListView):
     external_object_class = ImportSetup
@@ -310,7 +303,6 @@ class ImportSetupEditView(SingleObjectDynamicFormEditView):
     model = ImportSetup
     object_permission = permission_import_setup_edit
     pk_url_kwarg = 'import_setup_id'
-    post_action_redirect = reverse_lazy(viewname='importer:import_setup_list')
 
     def get_extra_context(self):
         return {
@@ -339,9 +331,6 @@ class ImportSetupClearView(MultipleObjectConfirmActionView):
     model = ImportSetup
     object_permission = permission_import_setup_process
     pk_url_kwarg = 'import_setup_id'
-    post_action_redirect = reverse_lazy(
-        viewname='importer:import_setup_list'
-    )
     success_message = _('%(count)d import setup cleared.')
     success_message_plural = _('%(count)d import setups cleared.')
 
@@ -404,24 +393,27 @@ class ImportSetupPopulateView(MultipleObjectConfirmActionView):
     post_action_redirect = reverse_lazy(
         viewname='importer:import_setup_list'
     )
-    success_message = _('%(count)d import setup preparation queued.')
-    success_message_plural = _('%(count)d import setups preparation queued.')
+    success_message = _('%(count)d import setup item population queued.')
+    success_message_plural = _('%(count)d import setups item population queued.')
 
     def get_extra_context(self):
         queryset = self.object_list
 
         result = {
             'message': _(
-                'This process will run in the background. Depending on the '
-                'number of files that match the import setup criteria, '
-                'the import backend, the size of the source repository, '
-                'and the bandwidth between Mayan EDMS and the source '
-                'repository, it may take between a few minutes to a few '
-                'days for the entire preparation process to complete.'
+                'This process will populate the items to import by querying '
+                'the source repository. The process will run in the '
+                'background and once starter, cannot be stopped from the '
+                'user interface. The time to completion will depend on the '
+                'number of files that match the import setup criteria, the '
+                'import backend, the size of the source repository, and '
+                'the bandwidth between Mayan EDMS and the source '
+                'repository. The completion may take between a few minutes '
+                'to a few days to complete.'
             ),
             'title': ungettext(
-                singular='Prepare the selected import setup?',
-                plural='Prepare the selected import setups?',
+                singular='Population the selected import setup?',
+                plural='Population the selected import setups?',
                 number=queryset.count()
             )
         }
@@ -493,7 +485,9 @@ class ImportSetupProcessView(MultipleObjectConfirmActionView):
             )
         else:
             task_import_setup_process.apply_async(
-                kwargs={'import_setup_id': instance.pk}
+                kwargs={
+                    'import_setup_id': instance.pk
+                }
             )
 
 
@@ -577,7 +571,7 @@ class ImportSetupItemDocumentListView(
                 ),
                 'title': _(
                     'Document created from import setup item: %s'
-                ) % self.external_object,
+                ) % self.external_object
             }
         )
         return context
@@ -593,11 +587,19 @@ class ImportSetupItemListView(ExternalObjectViewMixin, SingleObjectListView):
             'hide_link': True,
             'hide_object': True,
             'no_results_icon': icon_import_setup_items_list,
-            'no_results_main_link': link_import_setup_populate.resolve(
-                context=RequestContext(
-                    dict_={'object': self.external_object},
-                    request=self.request
-                )
+            'no_results_secondary_links': (
+                link_import_setup_populate.resolve(
+                    context=RequestContext(
+                        dict_={'object': self.external_object},
+                        request=self.request
+                    )
+                ),
+                link_model_filer_load.resolve(
+                    context=RequestContext(
+                        dict_={'object': self.external_object},
+                        request=self.request
+                    )
+                ),
             ),
             'no_results_text': _(
                 'Import setups items are the entries for the actual '
@@ -605,7 +607,7 @@ class ImportSetupItemListView(ExternalObjectViewMixin, SingleObjectListView):
             ),
             'no_results_title': _('No import setups items available'),
             'object': self.external_object,
-            'title': _('Items of import setup: %s') % self.external_object,
+            'title': _('Items of import setup: %s') % self.external_object
         }
 
     def get_source_queryset(self):
@@ -678,14 +680,13 @@ class ImportSetupItemLoadView(ExternalObjectViewMixin, FormView):
         full_model_name = ModelFiler.get_full_model_name(
             model=self.external_object.items.model
         )
-        task = task_model_filer_load.apply_async(
+        task_model_filer_load.apply_async(
             kwargs={
                 'field_defaults': {'import_setup_id': self.external_object.pk},
                 'full_model_name': full_model_name,
                 'shared_upload_file_id': shared_upload_file.pk
             }
         )
-        self.shared_upload_file_id = task.get()
 
         messages.success(
             message=_('File uploaded and queued for loading as models.'),
@@ -697,10 +698,10 @@ class ImportSetupItemLoadView(ExternalObjectViewMixin, FormView):
 
     def get_extra_context(self):
         return {
-            'object': self.get_external_object(),
+            'object': self.external_object,
             'title': _(
                 'Load the items of import setup: %s'
-            ) % self.get_external_object()
+            ) % self.external_object
         }
 
     def get_instance_extra_data(self):
@@ -716,10 +717,10 @@ class ImportSetupItemSaveConfirmView(ExternalObjectViewMixin, ConfirmView):
 
     def get_extra_context(self):
         return {
-            'object': self.get_external_object(),
+            'object': self.external_object,
             'title': _(
                 'Save the items of import setup: %s'
-            ) % self.get_external_object()
+            ) % self.external_object
         }
 
     def get_instance_extra_data(self):
@@ -727,33 +728,24 @@ class ImportSetupItemSaveConfirmView(ExternalObjectViewMixin, ConfirmView):
             '_event_actor': self.request.user,
         }
 
-    def get_success_url(self):
-        return reverse(
-            viewname='importer:import_setup_save_download', kwargs={
-                'shared_upload_file_id': self.shared_upload_file_id
-            }
-        )
-
     def view_action(self):
         full_model_name = ModelFiler.get_full_model_name(
             model=self.external_object.items.model
         )
 
-        task = task_model_filer_save.apply_async(
+        task_model_filer_save.apply_async(
             kwargs={
                 'filter_kwargs': {'import_setup': self.external_object.pk},
                 'full_model_name': full_model_name,
+                'save_file_title': str(
+                    _('Import setup "%s"') % self.external_object
+                ),
+                'organization_installation_url': get_organization_installation_url(
+                    request=self.request
+                ),
+                'user_id': self.request.user.pk
             }
         )
-        self.shared_upload_file_id = task.get()
-
-
-class ImportSetupItemSaveDownloadView(SingleObjectDownloadView):
-    model = SharedUploadedFile
-    pk_url_kwarg = 'shared_upload_file_id'
-
-    def get_download_filename(self):
-        return '{}.csv'.format(self.object)
 
 
 class ImportSetupLogListView(ExternalObjectViewMixin, SingleObjectListView):
@@ -775,7 +767,7 @@ class ImportSetupLogListView(ExternalObjectViewMixin, SingleObjectListView):
             'object': self.external_object,
             'title': _(
                 'Log entries for import setup: %s'
-            ) % self.external_object,
+            ) % self.external_object
         }
 
     def get_source_queryset(self):
